@@ -1,8 +1,9 @@
-# Copyright (C) 2003-2005, G. Allen Morris III, all rights reserved
+# Copyright (C) 2003-2007, G. Allen Morris III, all rights reserved
 
 use strict;
 
-package Data::Tabular::Output;
+package
+    Data::Tabular::Output;
 
 use Carp qw (croak);
 
