@@ -1,8 +1,10 @@
-# Copyright (C) 2003-2005, G. Allen Morris III, all rights reserved
+# Copyright (C) 2003-2007, G. Allen Morris III, all rights reserved
 
 use strict;
 
-package Data::Tabular::Row::Data;
+package
+    Data::Tabular::Row::Data;
+
 use base 'Data::Tabular::Row';
 
 sub html_attribute_string
@@ -18,7 +20,7 @@ sub html_attribute_string
     $ret;
 }
 
-sub headers
+sub _headers
 {
     my $self = shift;
     if ($self->{headers}) {
