@@ -1,7 +1,8 @@
-# Copyright (C) 2003-2005, G. Allen Morris III, all rights reserved
+# Copyright (C) 2003-2007, G. Allen Morris III, all rights reserved
 
 use strict;
-package Data::Tabular::Row::Group;
+package
+    Data::Tabular::Row::Group;
 
 use base 'Data::Tabular::Row';
 
