@@ -1,4 +1,4 @@
-# Copyright (C) 2003-2005, G. Allen Morris III, all rights reserved
+# Copyright (C) 2003-2007, G. Allen Morris III, all rights reserved
 
 use strict;
 
@@ -60,7 +60,7 @@ sub columns
 	} @headers);
 }
 
-sub title
+sub _title
 {
     my $self = shift;
     my $column_name = shift;
@@ -94,7 +94,7 @@ __END__
 
 =head1 NAME
 
-Data::Tabular::Table;
+Data::Tabular::Table
 
 =head1 SYNOPSIS
 
